@@ -5,7 +5,7 @@ import websockets
 import json
 from igloo.mutations import MutationRoot
 from igloo.subscriptions import SubscriptionRoot
-from igloo.utils import get_from_dict
+from igloo.utils import get_from_dict, _Undefined, UNDEFINED, undefined
 from aiohttp import ClientSession
 from .query import QueryRoot
 import asyncio
@@ -14,20 +14,6 @@ host = "api.igloo.ooo"
 url = "https://{}/graphql".format(host)
 
 
-class _Null:
-    def __str__(self):
-        return 'null'
-
-    def __unicode__(self):
-        return u'null'
-
-    def __repr__(self):
-        return 'null'
-
-
-NULL = null = _Null()
-
-
 class GraphQLException(Exception):
     pass
 
