@@ -1,5 +1,11 @@
 from datetime import datetime
-from igloo import _Undefined
+
+
+class _Undefined:
+    pass
+
+
+UNDEFINED = undefined = _Undefined()
 
 
 def get_from_dict(d, keys):
